@@ -209,8 +209,10 @@ def load_pytest_conf(path, parser):
     return namespace.get("CustomPyTester", PyTester)
 
 
-def project_root(parser, projdir=os.getcwd()):
+def project_root(parser, projdir=None):
     """try to find project's root and add it to sys.path"""
+    if projdir is None:
+        projdir = os.getcwd()
     previousdir = curdir = osp.abspath(projdir)
     testercls = PyTester
     conf_file_path = osp.join(curdir, CONF_FILE)
@@ -256,8 +258,7 @@ class GlobalTestReport(object):
             self.errmodules.append((filename[:-3], problems, ran))
 
     def failed_to_test_module(self, filename):
-        """called when the test module could not be imported by unittest
-        """
+        """called when the test module could not be imported by unittest"""
         self.errors += 1
         self.modulescount += 1
         self.ran += 1
@@ -578,8 +579,7 @@ class DjangoTester(PyTester):
 
 
 def make_parser():
-    """creates the OptionParser instance
-    """
+    """creates the OptionParser instance"""
     from optparse import OptionParser
 
     parser = OptionParser(usage=PYTEST_DOC)
@@ -888,7 +888,7 @@ Examples:
         )
 
         def removeSucceededTests(obj, succTests):
-            """ Recursive function that removes succTests from
+            """Recursive function that removes succTests from
             a TestSuite or TestCase
             """
             if isinstance(obj, unittest.TestSuite):
@@ -1329,8 +1329,7 @@ class NonStrictTestLoader(unittest.TestLoader):
         return any([(pat in testedname) for pat in self.skipped_patterns])  # type: ignore
 
     def getTestCaseNames(self, testCaseClass: type) -> List[str]:
-        """Return a sorted sequence of method names found within testCaseClass
-        """
+        """Return a sorted sequence of method names found within testCaseClass"""
         is_skipped = self._this_is_skipped
         classname = testCaseClass.__name__
         if classname[0] == "_" or is_skipped(classname):
