@@ -611,8 +611,7 @@ class Registry(dict):
             self.warning("can't remove %s, no id %s in the registry", objid, oid)
 
     def all_objects(self):
-        """return a list containing all objects in this registry.
-        """
+        """return a list containing all objects in this registry."""
         result = []
         for objs in self.values():
             result += objs
@@ -741,8 +740,7 @@ class Registry(dict):
         return self.selected(winners[0], args, kwargs)
 
     def selected(self, winner, args, kwargs):
-        """override here if for instance you don't want "instanciation"
-        """
+        """override here if for instance you don't want "instanciation" """
         return winner(*args, **kwargs)
 
     # these are overridden by set_log_methods below
